nocrypto

package
v0.0.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2018 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() (crypto.EMCrypto, error)

New registers this crypto type for use by the NetAuth server.

Types

type NoCrypto

type NoCrypto struct{}

NoCrypto binds the functions required by the crypto.Engine interface.

func (*NoCrypto) SecureSecret

func (n *NoCrypto) SecureSecret(s string) (string, error)

SecureSecret returns the secret unmodified.

func (*NoCrypto) VerifySecret

func (n *NoCrypto) VerifySecret(s, h string) error

VerifySecret performs a string equality check to determine if the secret is legitimate.

Jump to